
******************************************************************************
********************************** Import Data *******************************
******************************************************************************

ssc install rangestat

clear
cd "`c(pwd)'"
insheet using "quarter.csv", clear
set more off
gen t=_n
gen quarter=tq(1959q1)+t-1
format quarter %tq
tsset quarter

*** transform to real ***

gen rcd=100*(tcd/cpi)
gen rr_ratio= required_reserves/ tcd


gen lrcd=ln(rcd)
replace ffr=ffr/100

*** HP filter ***


tsfilter hp crd = lrcd, smooth(1600) trend(tcrd)


*** calculate volatility ***

rangestat (sd) crd, interval(quarter -20 20)

drop if quarter<tq(1965q1)
drop if quarter>tq(2013q4)



** from quarterly to annual series **

collapse (mean) ffr crd_sd rr_ratio , by(year)
tsset year




twoway (lfitci  crd_sd rr_ratio )  ///
       (scatter crd_sd rr_ratio, mcolor(black))  , ///
	 graphregion(fcolor(white)  lcolor(white)) ///
	  legend(off)  ///
	  xtitle("Required Reserves Ratio", size(large)) ytitle("Volatility of Inside Money", size(large))
graph export "scatter.pdf", as(pdf) replace	 		
  


egen mcdsd=mean(crd_sd)
egen mrr_ratio=mean(rr_ratio)
egen mffr=mean(ffr)
gen dmcdsd=crd_sd- mcdsd
gen dmrr_ratio=rr_ratio-mrr_ratio
gen dmffr=ffr-mffr



******************************************************
pperron dmffr
dfuller dmffr, lag(1)

pperron dmrr_ratio
dfuller dmrr_ratio, lag(1)

pperron dmcdsd
dfuller dmcdsd, lag(1)

pperron d.dmffr
dfuller d.dmffr, lag(1)

pperron d.dmrr_ratio
dfuller d.dmrr_ratio, lag(1)

pperron d.dmcdsd
dfuller d.dmcdsd, lag(1)


******************************************************

reg crd_sd rr_ratio   


newey crd_sd rr_ratio      , lag(1)

cointreg  crd_sd rr_ratio ffr, est(ccr) kernel(qs)  vic(bic)


vecrank crd_sd rr_ratio
vecrank crd_sd rr_ratio ffr




******************************************************






******************************************************************************
**********************************Quarterly***********************************
******************************************************************************

clear
cd "`c(pwd)'"
insheet using "quarter.csv", clear
set more off
gen t=_n
gen quarter=tq(1959q1)+t-1
format quarter %tq
tsset quarter

*** transform to real ***

gen rcd=100*(tcd/cpi)
gen rr_ratio= required_reserves/ tcd


gen lrcd=ln(rcd)
replace ffr=ffr/100

*** HP filter ***


tsfilter hp crd = lrcd, smooth(1600) trend(tcrd)


*** calculate volatility ***

rangestat (sd) crd, interval(quarter -20 20)

drop if quarter<tq(1965q1)
drop if quarter>tq(2013q4)





egen mcdsd=mean(crd_sd)


egen mrr_ratio=mean(rr_ratio)
egen mffr=mean(ffr)

gen dmcdsd=crd_sd- mcdsd


gen dmrr_ratio=rr_ratio-mrr_ratio
gen dmffr=ffr-mffr

******************************************************


pperron dmffr
dfuller dmffr, lag(1)

pperron dmrr_ratio
dfuller dmrr_ratio, lag(1)

pperron dmcdsd
dfuller dmcdsd, lag(1)

pperron d.dmffr
dfuller d.dmffr, lag(1)

pperron d.dmrr_ratio
dfuller d.dmrr_ratio, lag(1)

pperron d.dmcdsd
dfuller d.dmcdsd, lag(1)

